/**
 * Copyright 2018 Buypass AS, Oslo, Norway
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package no.buypass.code.api.isam;

public class Authenticator {

    /**
     * The Authenticator owner's userId, typically a phone number
     */
    private final String userId;

    /**
     * The Authenticator id (App-ID).
     */
    private final String appId;

    private Authenticator(Builder builder) {
        userId = builder.userId;
        appId = builder.appId;
    }

    public String getUserId() {
        return userId;
    }

    public String getAppId() {
        return appId;
    }

    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String userId;
        private String appId;

        private Builder() {
        }

        public Builder userId(String val) {
            userId = val;
            return this;
        }

        public Builder appId(String val) {
            appId = val;
            return this;
        }

        public Authenticator build() {
            return new Authenticator(this);
        }
    }
}
