/**
 * Copyright 2018 Buypass AS, Oslo, Norway
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package no.buypass.code.api.isam.extension;

import com.ibm.security.access.extension.authn.message.Cookie;
import com.ibm.security.access.extension.authn.message.Request;
import org.glassfish.jersey.internal.util.collection.MultivaluedStringMap;

import java.io.InputStream;
import java.util.List;

/**
 *
 */
public class TestRequest implements Request {

    private final String method;

    private final String uri;

    private final MultivaluedStringMap parameters;

    private TestRequest(Builder builder) {
        method = builder.method;
        uri = builder.uri;
        parameters = builder.parameters;
    }

    public static Builder newBuilder() {
        return new Builder();
    }

    @Override
    public String getMethod() {
        return method;
    }

    @Override
    public String getUri() {
        return uri;
    }

    @Override
    public String getHeader(String s) {
        return null;
    }

    @Override
    public List<String> getHeaders(String s) {
        return null;
    }

    @Override
    public List<Cookie> getCookies() {
        return null;
    }

    @Override
    public InputStream getBody() {
        return null;
    }

    @Override
    public String getParameter(String key) {
        return parameters.getFirst(key);
    }

    @Override
    public List<String> getParameters(String key) {
        return parameters.get(key);
    }


    public static final class Builder {
        private String method;
        private String uri;
        private final MultivaluedStringMap parameters;

        private Builder() {
            parameters = new MultivaluedStringMap();
        }

        public Builder method(String val) {
            method = val;
            return this;
        }

        public Builder uri(String val) {
            uri = val;
            return this;
        }

        public Builder addParameter(String key, String value) {
            parameters.putSingle(key, value);
            return this;
        }

        public TestRequest build() {
            return new TestRequest(this);
        }
    }
}
