/**
 * Copyright 2018 Buypass AS, Oslo, Norway
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package no.buypass.code.api.isam.ldap;

import com.google.common.collect.ImmutableList;
import com.unboundid.ldap.listener.InMemoryDirectoryServer;
import com.unboundid.ldap.listener.InMemoryDirectoryServerConfig;
import com.unboundid.ldif.LDIFReader;
import no.buypass.code.api.isam.Authenticator;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import java.io.InputStream;
import java.util.Collections;
import java.util.List;

import static org.assertj.core.api.Assertions.assertThat;

/**
 *
 */
public class DefaultLdapLookupTest {

    private static final String LDIF_FILE_PATH = "/ldif/test-server.ldif";

    private InMemoryDirectoryServer directoryServer;

    @Before
    public void setup() throws Exception {

        String baseDn1 = "ou=Groups,dc=example,dc=com";
        String baseDn2 = "ou=People,dc=example,dc=com";

        InMemoryDirectoryServerConfig config = new InMemoryDirectoryServerConfig(baseDn1, baseDn2);

        directoryServer = new InMemoryDirectoryServer(config);

        InputStream ldifStream = getClass().getResourceAsStream(LDIF_FILE_PATH);
        LDIFReader ldifReader = new LDIFReader(ldifStream);
        directoryServer.importFromLDIF(true, ldifReader);

        // start the listener
        directoryServer.startListening();
    }

    @After
    public void tearDown() {
        if (directoryServer != null) {
            directoryServer.shutDown(true);
        }
    }

    @Test
    public void testLookup() {
        int port = directoryServer.getListenPort();
        String ldapProviderUrl = "ldap://localhost:" + port;
        String ldapSecurityPrincipal = "uid=admin,ou=People,dc=example,dc=com";
        String ldapSecurityCredentials = "admin";
        List<String> ldapPhoneNumberAttrNames = ImmutableList.of("telephonenumber");
        List<String> ldapAppIdAttrNames = Collections.emptyList();
        String ldapBaseDn = "ou=People,dc=example,dc=com";
        String ldapUserAttrName = "uid";

        DefaultLdapLookup ldapLookup = new DefaultLdapLookup(ldapProviderUrl, ldapSecurityPrincipal, ldapSecurityCredentials, ldapPhoneNumberAttrNames, ldapAppIdAttrNames, ldapBaseDn, ldapUserAttrName);
        Authenticator authenticator = ldapLookup.resolve("abarnes");

        assertThat(authenticator.getUserId()).isEqualTo("+1 408 555 9445");
    }

}
